@@ -8,4 +8,4 @@ classname = "adi.ad9144"
 @pytest.mark.parametrize("classname", [(classname)])
 @pytest.mark.parametrize("channel", [0, 1, [0, 1]])
 def test_ad9144_tx_data(test_dma_tx, iio_uri, classname, channel):
-    test_dma_tx(iio_uri, classname, hardware, channel)
+    test_dma_tx(iio_uri, classname, channel)
